
What is Tox?
--------------------


.. image:: https://img.shields.io/pypi/v/tox.svg
   :target: https://pypi.org/project/tox/
.. image:: https://img.shields.io/pypi/pyversions/tox.svg
  :target: https://pypi.org/project/tox/
.. image:: https://travis-ci.org/tox-dev/tox.svg?branch=master
    :target: https://travis-ci.org/tox-dev/tox
.. image:: https://img.shields.io/appveyor/ci/RonnyPfannschmidt/tox/master.svg
    :target: https://ci.appveyor.com/project/RonnyPfannschmidt/tox


Tox is a generic virtualenv management and test command line tool you can use for:

* checking your package installs correctly with different Python versions and
  interpreters

* running your tests in each of the environments, configuring your test tool of choice

* acting as a frontend to Continuous Integration servers, greatly
  reducing boilerplate and merging CI and shell-based testing.

For more information and the repository please checkout:

- home and docs: https://tox.readthedocs.org

- repository: https://github.com/tox-dev/tox

